
#include <mingpp.h>

int main()
{
  Ming_init();
  Ming_setScale(1.0);

  SWFMovie *m = new SWFMovie();
  m->setRate(12.0);
  m->setSoundStream(new SWFSound(fopen("../common/distortobass.mp3", "rb")));

  // 11.85 seconds at 12.0 fps = 142 frames
  m->setFrames(142);

  m->save("test.swf");

  exit(0);
}
