
#include <mingpp.h>

int main()
{
  Ming_init();
  Ming_setScale(1.0);

  SWFFont *f = new SWFFont("../common/test.fdb");
  SWFText *t = new SWFText();

  t->setFont(f);
  t->moveTo(200, 2400);
  t->setColor(0xff, 0xff, 0);
  t->setHeight(1200);
  t->addString("fnar! fnar!");

  SWFMovie *m = new SWFMovie();
  m->setDimension(5400, 3600);

  m->add(t);

  m->save("test.swf");

  exit(0);
}
