
#include <mingpp.h>

int main()
{
  Ming_init();
  Ming_setScale(1.0);

  SWFShape *s = new SWFShape();
  s->setLine(40, 0x7f, 0, 0);
  s->setRightFill(s->addSolidFill(0xff, 0, 0));
  s->movePenTo(200, 200);
  s->drawLineTo(6200, 200);
  s->drawLineTo(6200, 4600);
  s->drawCurveTo(200, 4600, 200, 200);

  SWFMovie *m = new SWFMovie();
  m->setDimension(6400, 4800);
  m->setRate(12.0);
  m->add(s);
  m->nextFrame();

  m->save("test.swf");

  exit(0);
}
