
#include <mingpp.h>

int main()
{
  Ming_init();
  Ming_setScale(1.0);

  SWFMovie *m = new SWFMovie();
  m->setDimension(320, 240);

  SWFShape *s = new SWFShape();

  // first gradient- black to white
  SWFGradient *g = new SWFGradient();
  g->addEntry(0.0, 0, 0, 0);
  g->addEntry(1.0, 0xff, 0xff, 0xff);

  SWFFill *f = s->addGradientFill(g, SWFFILL_LINEAR_GRADIENT);
  f->scaleTo(0.01);
  f->moveTo(160, 120);

  s->setRightFill(f);
  s->drawLine(320, 0);
  s->drawLine(0, 240);
  s->drawLine(-320, 0);
  s->drawLine(0, -240);

  m->add(s);

  s = new SWFShape();

  // second gradient- radial gradient from white to red to transparent
  g = new SWFGradient();
  g->addEntry(0.0, 0xff, 0, 0, 0xff);
  g->addEntry(1.0, 0xff, 0, 0, 0);

  f = s->addGradientFill(g, SWFFILL_RADIAL_GRADIENT);
  f->scaleTo(0.005);
  f->moveTo(160, 120);

  s->setRightFill(f);
  s->drawLine(320, 0);
  s->drawLine(0, 240);
  s->drawLine(-320, 0);
  s->drawLine(0, -240);

  m->add(s);

  m->save("test.swf");

  exit(0);
}
