
#include <mingpp.h>

int main()
{
  Ming_init();
  Ming_setScale(1.0);

  SWFShape *s = new SWFShape();
  SWFFill *f = s->addBitmapFill(new SWFBitmap("../common/png.dbl"));
  s->setRightFill(f);

  s->drawLine(32, 0);
  s->drawLine(0, 32);
  s->drawLine(-32, 0);
  s->drawLine(0, -32);

  SWFMovie *m = new SWFMovie();
  m->setDimension(32, 32);
  m->add(s);

  m->save("test.swf");

  exit(0);
}
