
#include "ming.h"

int main()
{
  SWFFont f;
  SWFText t;
  SWFMovie m;

  Ming_init();
  Ming_setScale(1.0);

  f = loadSWFFontFromFile(fopen("../common/test.fdb", "rb"));
  t = newSWFText2();

  SWFText_setFont(t, f);
  SWFText_moveTo(t, 200, 2400);
  SWFText_setColor(t, 0xff, 0xff, 0, 0xff);
  SWFText_setHeight(t, 1200);
  SWFText_addString(t, "fnar! fnar!", NULL);

  m = newSWFMovie();
  SWFMovie_setDimension(m, 5400, 3600);

  SWFMovie_add(m, t);

  SWFMovie_save(m, "test.swf");

  exit(0);
}
