
#include "ming.h"

int main()
{
  SWFShape s;
  SWFMovie m;

  Ming_init();
  Ming_setScale(1.0);

  s = newSWFShape();
  SWFShape_setLine(s, 40, 0x7f, 0, 0, 0xff);
  SWFShape_setRightFill(s, SWFShape_addSolidFill(s, 0xff, 0, 0, 0xff));
  SWFShape_movePenTo(s, 200, 200);
  SWFShape_drawLineTo(s, 6200, 200);
  SWFShape_drawLineTo(s, 6200, 4600);
  SWFShape_drawCurveTo(s, 200, 4600, 200, 200);

  m = newSWFMovie();
  SWFMovie_setDimension(m, 6400, 4800);
  SWFMovie_setRate(m, 12.0);
  SWFMovie_add(m, s);
  SWFMovie_nextFrame(m);

  SWFMovie_save(m, "test.swf");

  exit(0);
}
