
#include "ming.h"

int main()
{
  SWFMovie m;

  Ming_init();
  Ming_setScale(1.0);

  m = newSWFMovie();
  SWFMovie_setRate(m, 12.0);
  SWFMovie_setSoundStream(m, newSWFSound(fopen("../common/distortobass.mp3", "rb")));

  // 11.85 seconds at 12.0 fps = 142 frames
  SWFMovie_setFrames(m, 142);

  SWFMovie_save(m, "test.swf");

  exit(0);
}
